import { useSanityVisualEditingState } from "../composables/useSanityVisualEditingState.js";
import useSanityClient from "../utils/useSanityClient.js";
import { defineNuxtPlugin, useCookie, useRuntimeConfig } from "#imports";
export default defineNuxtPlugin(async () => {
  const visualEditingState = useSanityVisualEditingState();
  const $config = useRuntimeConfig();
  const { visualEditing } = $config.public.sanity;
  if (import.meta.server) {
    const previewModeId = $config.sanity.visualEditing.previewModeId;
    if (visualEditing?.previewMode && previewModeId) {
      const previewModeCookie = useCookie("__sanity_preview");
      visualEditingState.enabled = previewModeId === previewModeCookie.value;
    }
  } else if (visualEditingState.enabled) {
    switch (visualEditing?.mode) {
      case "live-visual-editing":
      case "visual-editing":
        import("../utils/visualEditing/enableVisualEditing.js").then(({ enableVisualEditing }) => enableVisualEditing({
          refresh: visualEditing?.refresh,
          zIndex: visualEditing?.zIndex
        }));
        if (visualEditing?.mode === "live-visual-editing") {
          const client = await useSanityClient(true, "default", $config.public.sanity);
          client.queryStore?.enableLiveMode({ client: client.client });
        }
        break;
    }
  }
});
